@@ -1,6 +1,7 @@
-from .leagueinfo import LeagueInfo
-from .managerinfo import ManagerInfo
-from .playerinfo import PlayerInfo
+from .league_info import LeagueInfo
+from .manager_info import ManagerInfo
+from .player_info import PlayerInfo
+from .transaction_info import TransactionInfo
 
 import logging
 
